pub fn set_mode(mode: AppearanceMode, cx: &mut App)Expand description
Change the user’s preference and repaint if that changed the palette. Persisting the choice is the caller’s job.
pub fn set_mode(mode: AppearanceMode, cx: &mut App)Change the user’s preference and repaint if that changed the palette. Persisting the choice is the caller’s job.